@@ -228,6 +228,22 @@ class Neighborhood {
         return const_iterator(this, std::distance(neighbors.begin(), it));
     }
 
+    /**
+     * Total bytes consumed by the biases and indices.
+     *
+     * If `capacity` is true, use the capacity of the underlying vectors rather
+     * than the size.
+     */
+    size_type nbytes(bool capacity = false) const noexcept {
+        if (capacity) {
+            return this->neighbors.capacity() * sizeof(index_type) +
+                   this->quadratic_biases.capacity() * sizeof(bias_type);
+        } else {
+            return this->neighbors.size() * sizeof(index_type) +
+                   this->quadratic_biases.size() * sizeof(bias_type);
+        }
+    }
+
     /**
      * Return the bias at neighbor `v` or the default value.
      *
@@ -391,7 +407,7 @@ class QuadraticModelBase {
             en += u_val * linear(u);
 
             auto span = neighborhood(u);
-            for (auto nit = span.first; nit != span.second && (*nit).first < u;
+            for (auto nit = span.first; nit != span.second && (*nit).first <= u;
                  ++nit) {
                 auto v_val = *(sample_start + (*nit).first);
                 auto bias = (*nit).second;
@@ -469,6 +485,25 @@ class QuadraticModelBase {
         return adj_[u].at(v);
     }
 
+    /**
+     * Total bytes consumed by the biases and indices.
+     *
+     * If `capacity` is true, use the capacity of the underlying vectors rather
+     * than the size.
+     */
+    size_type nbytes(bool capacity = false) const noexcept {
+        size_type count = sizeof(bias_type);  // offset
+        if (capacity) {
+            count += this->linear_biases_.capacity() * sizeof(bias_type);
+        } else {
+            count += this->linear_biases_.size() * sizeof(bias_type);
+        }
+        for (size_type v = 0; v < this->num_variables(); ++v) {
+            count += this->adj_[v].nbytes(capacity);
+        }
+        return count;
+    }
+
     /// Return the number of variables in the quadratic model.
     size_type num_variables() const { return linear_biases_.size(); }
 
@@ -1154,6 +1189,22 @@ class QuadraticModel : public QuadraticModelBase<Bias, Index> {
         return vartype_limits<bias_type, Vartype::INTEGER>::max();
     }
 
+    /**
+     * Total bytes consumed by the biases, vartype info, bounds, and indices.
+     *
+     * If `capacity` is true, use the capacity of the underlying vectors rather
+     * than the size.
+     */
+    size_type nbytes(bool capacity = false) const noexcept {
+        size_type count = base_type::nbytes(capacity);
+        if (capacity) {
+            count += this->varinfo_.capacity() * sizeof(VarInfo<bias_type>);
+        } else {
+            count += this->varinfo_.size() * sizeof(VarInfo<bias_type>);
+        }
+        return count;
+    }
+
     // Resize the model to contain `n` variables.
     void resize(index_type n) {
         // we could do this as an assert, but let's be careful since
